# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class ListSearchRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"list_ids": "list[str]", "offset": "int", "query": "str", "count": "int", "processing_types": "list[str]", "additional_properties": "list[str]", "sort": "str"}

    attribute_map = {
        "list_ids": "listIds",
        "offset": "offset",
        "query": "query",
        "count": "count",
        "processing_types": "processingTypes",
        "additional_properties": "additionalProperties",
        "sort": "sort",
    }

    def __init__(self, list_ids=None, offset=None, query=None, count=None, processing_types=None, additional_properties=None, sort=None, local_vars_configuration=None):  # noqa: E501
        """ListSearchRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._list_ids = None
        self._offset = None
        self._query = None
        self._count = None
        self._processing_types = None
        self._additional_properties = None
        self._sort = None
        self.discriminator = None

        if list_ids is not None:
            self.list_ids = list_ids
        if offset is not None:
            self.offset = offset
        if query is not None:
            self.query = query
        if count is not None:
            self.count = count
        if processing_types is not None:
            self.processing_types = processing_types
        if additional_properties is not None:
            self.additional_properties = additional_properties
        if sort is not None:
            self.sort = sort

    @property
    def list_ids(self):
        """Gets the list_ids of this ListSearchRequest.  # noqa: E501

        The `listIds` that will be used to filter results by `listId`. If values are provided, then the response will only include results that have a `listId` in this array.  If no value is provided, or if an empty list is provided, then the results will not be filtered by `listId`.  # noqa: E501

        :return: The list_ids of this ListSearchRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._list_ids

    @list_ids.setter
    def list_ids(self, list_ids):
        """Sets the list_ids of this ListSearchRequest.

        The `listIds` that will be used to filter results by `listId`. If values are provided, then the response will only include results that have a `listId` in this array.  If no value is provided, or if an empty list is provided, then the results will not be filtered by `listId`.  # noqa: E501

        :param list_ids: The list_ids of this ListSearchRequest.  # noqa: E501
        :type list_ids: list[str]
        """

        self._list_ids = list_ids

    @property
    def offset(self):
        """Gets the offset of this ListSearchRequest.  # noqa: E501

        Value used to paginate through lists. The `offset` provided in the response can be used in the next request to fetch the next page of results. Defaults to `0` if no offset is provided.  # noqa: E501

        :return: The offset of this ListSearchRequest.  # noqa: E501
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ListSearchRequest.

        Value used to paginate through lists. The `offset` provided in the response can be used in the next request to fetch the next page of results. Defaults to `0` if no offset is provided.  # noqa: E501

        :param offset: The offset of this ListSearchRequest.  # noqa: E501
        :type offset: int
        """

        self._offset = offset

    @property
    def query(self):
        """Gets the query of this ListSearchRequest.  # noqa: E501

        The `query` that will be used to search for lists by list name. If no `query` is provided, then the results will include all lists.  # noqa: E501

        :return: The query of this ListSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this ListSearchRequest.

        The `query` that will be used to search for lists by list name. If no `query` is provided, then the results will include all lists.  # noqa: E501

        :param query: The query of this ListSearchRequest.  # noqa: E501
        :type query: str
        """

        self._query = query

    @property
    def count(self):
        """Gets the count of this ListSearchRequest.  # noqa: E501

        The number of lists to include in the response. Defaults to `20` if no value is provided. The max `count` is `500`.  # noqa: E501

        :return: The count of this ListSearchRequest.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ListSearchRequest.

        The number of lists to include in the response. Defaults to `20` if no value is provided. The max `count` is `500`.  # noqa: E501

        :param count: The count of this ListSearchRequest.  # noqa: E501
        :type count: int
        """

        self._count = count

    @property
    def processing_types(self):
        """Gets the processing_types of this ListSearchRequest.  # noqa: E501

        The `processingTypes` that will be used to filter results by `processingType`. If values are provided, then the response will only include results that have a `processingType` in this array.  If no value is provided, or if an empty list is provided, then results will not be filtered by `processingType`.  Valid `processingTypes` are: `MANUAL`, `SNAPSHOT`, or `DYNAMIC`.  # noqa: E501

        :return: The processing_types of this ListSearchRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._processing_types

    @processing_types.setter
    def processing_types(self, processing_types):
        """Sets the processing_types of this ListSearchRequest.

        The `processingTypes` that will be used to filter results by `processingType`. If values are provided, then the response will only include results that have a `processingType` in this array.  If no value is provided, or if an empty list is provided, then results will not be filtered by `processingType`.  Valid `processingTypes` are: `MANUAL`, `SNAPSHOT`, or `DYNAMIC`.  # noqa: E501

        :param processing_types: The processing_types of this ListSearchRequest.  # noqa: E501
        :type processing_types: list[str]
        """

        self._processing_types = processing_types

    @property
    def additional_properties(self):
        """Gets the additional_properties of this ListSearchRequest.  # noqa: E501

        The property names of any additional list properties to include in the response. Properties that do not exist or that are empty for a particular list are not included in the response.  By default, all requests will fetch the following properties for each list: `hs_list_size`, `hs_last_record_added_at`, `hs_last_record_removed_at`, `hs_folder_name`, and `hs_list_reference_count`.  # noqa: E501

        :return: The additional_properties of this ListSearchRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """Sets the additional_properties of this ListSearchRequest.

        The property names of any additional list properties to include in the response. Properties that do not exist or that are empty for a particular list are not included in the response.  By default, all requests will fetch the following properties for each list: `hs_list_size`, `hs_last_record_added_at`, `hs_last_record_removed_at`, `hs_folder_name`, and `hs_list_reference_count`.  # noqa: E501

        :param additional_properties: The additional_properties of this ListSearchRequest.  # noqa: E501
        :type additional_properties: list[str]
        """

        self._additional_properties = additional_properties

    @property
    def sort(self):
        """Gets the sort of this ListSearchRequest.  # noqa: E501


        :return: The sort of this ListSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this ListSearchRequest.


        :param sort: The sort of this ListSearchRequest.  # noqa: E501
        :type sort: str
        """

        self._sort = sort

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListSearchRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ListSearchRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    Transactional Single Send

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.marketing.transactional.models.collection_response_smtp_api_token_view_forward_paging import CollectionResponseSmtpApiTokenViewForwardPaging
from hubspot.marketing.transactional.models.email_send_status_view import EmailSendStatusView
from hubspot.marketing.transactional.models.error import Error
from hubspot.marketing.transactional.models.error_detail import ErrorDetail
from hubspot.marketing.transactional.models.event_id_view import EventIdView
from hubspot.marketing.transactional.models.forward_paging import ForwardPaging
from hubspot.marketing.transactional.models.next_page import NextPage
from hubspot.marketing.transactional.models.public_single_send_email import PublicSingleSendEmail
from hubspot.marketing.transactional.models.public_single_send_request_egg import PublicSingleSendRequestEgg
from hubspot.marketing.transactional.models.smtp_api_token_request_egg import SmtpApiTokenRequestEgg
from hubspot.marketing.transactional.models.smtp_api_token_view import SmtpApiTokenView



# coding: utf-8

"""
    Forms

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.forms.configuration import Configuration


class HubSpotFormDefinitionCreateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "form_type": "str",
        "name": "str",
        "created_at": "datetime",
        "updated_at": "datetime",
        "archived": "bool",
        "archived_at": "datetime",
        "field_groups": "list[FieldGroup]",
        "configuration": "HubSpotFormConfiguration",
        "display_options": "FormDisplayOptions",
        "legal_consent_options": "HubSpotFormDefinitionAllOfLegalConsentOptions",
    }

    attribute_map = {
        "form_type": "formType",
        "name": "name",
        "created_at": "createdAt",
        "updated_at": "updatedAt",
        "archived": "archived",
        "archived_at": "archivedAt",
        "field_groups": "fieldGroups",
        "configuration": "configuration",
        "display_options": "displayOptions",
        "legal_consent_options": "legalConsentOptions",
    }

    def __init__(
        self,
        form_type="hubspot",
        name=None,
        created_at=None,
        updated_at=None,
        archived=None,
        archived_at=None,
        field_groups=None,
        configuration=None,
        display_options=None,
        legal_consent_options=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """HubSpotFormDefinitionCreateRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._form_type = None
        self._name = None
        self._created_at = None
        self._updated_at = None
        self._archived = None
        self._archived_at = None
        self._field_groups = None
        self._configuration = None
        self._display_options = None
        self._legal_consent_options = None
        self.discriminator = None

        self.form_type = form_type
        self.name = name
        self.created_at = created_at
        self.updated_at = updated_at
        self.archived = archived
        if archived_at is not None:
            self.archived_at = archived_at
        self.field_groups = field_groups
        self.configuration = configuration
        self.display_options = display_options
        self.legal_consent_options = legal_consent_options

    @property
    def form_type(self):
        """Gets the form_type of this HubSpotFormDefinitionCreateRequest.  # noqa: E501


        :return: The form_type of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._form_type

    @form_type.setter
    def form_type(self, form_type):
        """Sets the form_type of this HubSpotFormDefinitionCreateRequest.


        :param form_type: The form_type of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :type form_type: str
        """
        if self.local_vars_configuration.client_side_validation and form_type is None:  # noqa: E501
            raise ValueError("Invalid value for `form_type`, must not be `None`")  # noqa: E501
        allowed_values = ["hubspot"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and form_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `form_type` ({0}), must be one of {1}".format(form_type, allowed_values))  # noqa: E501

        self._form_type = form_type

    @property
    def name(self):
        """Gets the name of this HubSpotFormDefinitionCreateRequest.  # noqa: E501


        :return: The name of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this HubSpotFormDefinitionCreateRequest.


        :param name: The name of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def created_at(self):
        """Gets the created_at of this HubSpotFormDefinitionCreateRequest.  # noqa: E501


        :return: The created_at of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this HubSpotFormDefinitionCreateRequest.


        :param created_at: The created_at of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this HubSpotFormDefinitionCreateRequest.  # noqa: E501


        :return: The updated_at of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this HubSpotFormDefinitionCreateRequest.


        :param updated_at: The updated_at of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :type updated_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def archived(self):
        """Gets the archived of this HubSpotFormDefinitionCreateRequest.  # noqa: E501


        :return: The archived of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this HubSpotFormDefinitionCreateRequest.


        :param archived: The archived of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :type archived: bool
        """
        if self.local_vars_configuration.client_side_validation and archived is None:  # noqa: E501
            raise ValueError("Invalid value for `archived`, must not be `None`")  # noqa: E501

        self._archived = archived

    @property
    def archived_at(self):
        """Gets the archived_at of this HubSpotFormDefinitionCreateRequest.  # noqa: E501


        :return: The archived_at of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._archived_at

    @archived_at.setter
    def archived_at(self, archived_at):
        """Sets the archived_at of this HubSpotFormDefinitionCreateRequest.


        :param archived_at: The archived_at of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :type archived_at: datetime
        """

        self._archived_at = archived_at

    @property
    def field_groups(self):
        """Gets the field_groups of this HubSpotFormDefinitionCreateRequest.  # noqa: E501


        :return: The field_groups of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :rtype: list[FieldGroup]
        """
        return self._field_groups

    @field_groups.setter
    def field_groups(self, field_groups):
        """Sets the field_groups of this HubSpotFormDefinitionCreateRequest.


        :param field_groups: The field_groups of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :type field_groups: list[FieldGroup]
        """
        if self.local_vars_configuration.client_side_validation and field_groups is None:  # noqa: E501
            raise ValueError("Invalid value for `field_groups`, must not be `None`")  # noqa: E501

        self._field_groups = field_groups

    @property
    def configuration(self):
        """Gets the configuration of this HubSpotFormDefinitionCreateRequest.  # noqa: E501


        :return: The configuration of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :rtype: HubSpotFormConfiguration
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this HubSpotFormDefinitionCreateRequest.


        :param configuration: The configuration of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :type configuration: HubSpotFormConfiguration
        """
        if self.local_vars_configuration.client_side_validation and configuration is None:  # noqa: E501
            raise ValueError("Invalid value for `configuration`, must not be `None`")  # noqa: E501

        self._configuration = configuration

    @property
    def display_options(self):
        """Gets the display_options of this HubSpotFormDefinitionCreateRequest.  # noqa: E501


        :return: The display_options of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :rtype: FormDisplayOptions
        """
        return self._display_options

    @display_options.setter
    def display_options(self, display_options):
        """Sets the display_options of this HubSpotFormDefinitionCreateRequest.


        :param display_options: The display_options of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :type display_options: FormDisplayOptions
        """
        if self.local_vars_configuration.client_side_validation and display_options is None:  # noqa: E501
            raise ValueError("Invalid value for `display_options`, must not be `None`")  # noqa: E501

        self._display_options = display_options

    @property
    def legal_consent_options(self):
        """Gets the legal_consent_options of this HubSpotFormDefinitionCreateRequest.  # noqa: E501


        :return: The legal_consent_options of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :rtype: HubSpotFormDefinitionAllOfLegalConsentOptions
        """
        return self._legal_consent_options

    @legal_consent_options.setter
    def legal_consent_options(self, legal_consent_options):
        """Sets the legal_consent_options of this HubSpotFormDefinitionCreateRequest.


        :param legal_consent_options: The legal_consent_options of this HubSpotFormDefinitionCreateRequest.  # noqa: E501
        :type legal_consent_options: HubSpotFormDefinitionAllOfLegalConsentOptions
        """
        if self.local_vars_configuration.client_side_validation and legal_consent_options is None:  # noqa: E501
            raise ValueError("Invalid value for `legal_consent_options`, must not be `None`")  # noqa: E501

        self._legal_consent_options = legal_consent_options

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HubSpotFormDefinitionCreateRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HubSpotFormDefinitionCreateRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    Tags

    Use these endpoints for interacting with Blog Posts, Blog Authors, and Blog Tags  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.cms.blogs.tags.models.attach_to_lang_primary_request_v_next import AttachToLangPrimaryRequestVNext
from hubspot.cms.blogs.tags.models.batch_input_json_node import BatchInputJsonNode
from hubspot.cms.blogs.tags.models.batch_input_string import BatchInputString
from hubspot.cms.blogs.tags.models.batch_input_tag import BatchInputTag
from hubspot.cms.blogs.tags.models.batch_response_tag import BatchResponseTag
from hubspot.cms.blogs.tags.models.batch_response_tag_with_errors import BatchResponseTagWithErrors
from hubspot.cms.blogs.tags.models.collection_response_with_total_tag_forward_paging import CollectionResponseWithTotalTagForwardPaging
from hubspot.cms.blogs.tags.models.detach_from_lang_group_request_v_next import DetachFromLangGroupRequestVNext
from hubspot.cms.blogs.tags.models.error import Error
from hubspot.cms.blogs.tags.models.error_detail import ErrorDetail
from hubspot.cms.blogs.tags.models.forward_paging import ForwardPaging
from hubspot.cms.blogs.tags.models.next_page import NextPage
from hubspot.cms.blogs.tags.models.set_new_language_primary_request_v_next import SetNewLanguagePrimaryRequestVNext
from hubspot.cms.blogs.tags.models.standard_error import StandardError
from hubspot.cms.blogs.tags.models.tag import Tag
from hubspot.cms.blogs.tags.models.tag_clone_request_v_next import TagCloneRequestVNext
from hubspot.cms.blogs.tags.models.update_languages_request_v_next import UpdateLanguagesRequestVNext



# coding: utf-8

# flake8: noqa

"""
    Timeline

    This feature allows an app to create and configure custom events that can show up in the timelines of certain CRM objects like contacts, companies, tickets, or deals. You'll find multiple use cases for this API in the sections below.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.timeline.api.events_api import EventsApi
from hubspot.crm.timeline.api.templates_api import TemplatesApi
from hubspot.crm.timeline.api.tokens_api import TokensApi

# import ApiClient
from hubspot.crm.timeline.api_client import ApiClient
from hubspot.crm.timeline.configuration import Configuration
from hubspot.crm.timeline.exceptions import OpenApiException
from hubspot.crm.timeline.exceptions import ApiTypeError
from hubspot.crm.timeline.exceptions import ApiValueError
from hubspot.crm.timeline.exceptions import ApiKeyError
from hubspot.crm.timeline.exceptions import ApiAttributeError
from hubspot.crm.timeline.exceptions import ApiException

# import models into sdk package
from hubspot.crm.timeline.models.batch_input_timeline_event import BatchInputTimelineEvent
from hubspot.crm.timeline.models.batch_response_timeline_event_response import BatchResponseTimelineEventResponse
from hubspot.crm.timeline.models.batch_response_timeline_event_response_with_errors import BatchResponseTimelineEventResponseWithErrors
from hubspot.crm.timeline.models.collection_response_timeline_event_template_no_paging import CollectionResponseTimelineEventTemplateNoPaging
from hubspot.crm.timeline.models.error import Error
from hubspot.crm.timeline.models.error_detail import ErrorDetail
from hubspot.crm.timeline.models.event_detail import EventDetail
from hubspot.crm.timeline.models.standard_error import StandardError
from hubspot.crm.timeline.models.timeline_event import TimelineEvent
from hubspot.crm.timeline.models.timeline_event_i_frame import TimelineEventIFrame
from hubspot.crm.timeline.models.timeline_event_response import TimelineEventResponse
from hubspot.crm.timeline.models.timeline_event_template import TimelineEventTemplate
from hubspot.crm.timeline.models.timeline_event_template_create_request import TimelineEventTemplateCreateRequest
from hubspot.crm.timeline.models.timeline_event_template_token import TimelineEventTemplateToken
from hubspot.crm.timeline.models.timeline_event_template_token_option import TimelineEventTemplateTokenOption
from hubspot.crm.timeline.models.timeline_event_template_token_update_request import TimelineEventTemplateTokenUpdateRequest
from hubspot.crm.timeline.models.timeline_event_template_update_request import TimelineEventTemplateUpdateRequest



import urllib

AUTHORIZE_URL = "https://app.hubspot.com/oauth/authorize"


def get_auth_url(
    client_id: str,
    redirect_uri: str,
    scope: tuple = None,
    optional_scope: tuple = None,
    state: str = None
) -> str:
    query_params = {
        "client_id": client_id,
        "redirect_uri": redirect_uri
    }

    if scope:
        query_params["scope"] = " ".join(scope)
    if optional_scope:
        query_params["optional_scope"] = " ".join(optional_scope)
    if state:
        query_params.setdefault("state", state)

    params = urllib.parse.urlencode(
        query_params,
        safe='',
        quote_via=urllib.parse.quote,
    )

    return f"{AUTHORIZE_URL}?{params}"



# coding: utf-8

# flake8: noqa

"""
    Tags

    Use these endpoints for interacting with Blog Posts, Blog Authors, and Blog Tags  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.cms.blogs.tags.api.blog_tags_api import BlogTagsApi

# import ApiClient
from hubspot.cms.blogs.tags.api_client import ApiClient
from hubspot.cms.blogs.tags.configuration import Configuration
from hubspot.cms.blogs.tags.exceptions import OpenApiException
from hubspot.cms.blogs.tags.exceptions import ApiTypeError
from hubspot.cms.blogs.tags.exceptions import ApiValueError
from hubspot.cms.blogs.tags.exceptions import ApiKeyError
from hubspot.cms.blogs.tags.exceptions import ApiAttributeError
from hubspot.cms.blogs.tags.exceptions import ApiException

# import models into sdk package
from hubspot.cms.blogs.tags.models.attach_to_lang_primary_request_v_next import AttachToLangPrimaryRequestVNext
from hubspot.cms.blogs.tags.models.batch_input_json_node import BatchInputJsonNode
from hubspot.cms.blogs.tags.models.batch_input_string import BatchInputString
from hubspot.cms.blogs.tags.models.batch_input_tag import BatchInputTag
from hubspot.cms.blogs.tags.models.batch_response_tag import BatchResponseTag
from hubspot.cms.blogs.tags.models.batch_response_tag_with_errors import BatchResponseTagWithErrors
from hubspot.cms.blogs.tags.models.collection_response_with_total_tag_forward_paging import CollectionResponseWithTotalTagForwardPaging
from hubspot.cms.blogs.tags.models.detach_from_lang_group_request_v_next import DetachFromLangGroupRequestVNext
from hubspot.cms.blogs.tags.models.error import Error
from hubspot.cms.blogs.tags.models.error_detail import ErrorDetail
from hubspot.cms.blogs.tags.models.forward_paging import ForwardPaging
from hubspot.cms.blogs.tags.models.next_page import NextPage
from hubspot.cms.blogs.tags.models.set_new_language_primary_request_v_next import SetNewLanguagePrimaryRequestVNext
from hubspot.cms.blogs.tags.models.standard_error import StandardError
from hubspot.cms.blogs.tags.models.tag import Tag
from hubspot.cms.blogs.tags.models.tag_clone_request_v_next import TagCloneRequestVNext
from hubspot.cms.blogs.tags.models.update_languages_request_v_next import UpdateLanguagesRequestVNext



# coding: utf-8

"""
    Properties

    All HubSpot objects store data in default and custom properties. These endpoints provide access to read and modify object properties in HubSpot.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.properties.configuration import Configuration


class ModelProperty(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "created_user_id": "str",
        "hidden": "bool",
        "modification_metadata": "PropertyModificationMetadata",
        "display_order": "int",
        "description": "str",
        "show_currency_symbol": "bool",
        "label": "str",
        "type": "str",
        "hubspot_defined": "bool",
        "form_field": "bool",
        "created_at": "datetime",
        "archived_at": "datetime",
        "archived": "bool",
        "group_name": "str",
        "referenced_object_type": "str",
        "name": "str",
        "options": "list[Option]",
        "calculation_formula": "str",
        "has_unique_value": "bool",
        "field_type": "str",
        "updated_user_id": "str",
        "calculated": "bool",
        "external_options": "bool",
        "updated_at": "datetime",
    }

    attribute_map = {
        "created_user_id": "createdUserId",
        "hidden": "hidden",
        "modification_metadata": "modificationMetadata",
        "display_order": "displayOrder",
        "description": "description",
        "show_currency_symbol": "showCurrencySymbol",
        "label": "label",
        "type": "type",
        "hubspot_defined": "hubspotDefined",
        "form_field": "formField",
        "created_at": "createdAt",
        "archived_at": "archivedAt",
        "archived": "archived",
        "group_name": "groupName",
        "referenced_object_type": "referencedObjectType",
        "name": "name",
        "options": "options",
        "calculation_formula": "calculationFormula",
        "has_unique_value": "hasUniqueValue",
        "field_type": "fieldType",
        "updated_user_id": "updatedUserId",
        "calculated": "calculated",
        "external_options": "externalOptions",
        "updated_at": "updatedAt",
    }

    def __init__(
        self,
        created_user_id=None,
        hidden=None,
        modification_metadata=None,
        display_order=None,
        description=None,
        show_currency_symbol=None,
        label=None,
        type=None,
        hubspot_defined=None,
        form_field=None,
        created_at=None,
        archived_at=None,
        archived=None,
        group_name=None,
        referenced_object_type=None,
        name=None,
        options=None,
        calculation_formula=None,
        has_unique_value=None,
        field_type=None,
        updated_user_id=None,
        calculated=None,
        external_options=None,
        updated_at=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """ModelProperty - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_user_id = None
        self._hidden = None
        self._modification_metadata = None
        self._display_order = None
        self._description = None
        self._show_currency_symbol = None
        self._label = None
        self._type = None
        self._hubspot_defined = None
        self._form_field = None
        self._created_at = None
        self._archived_at = None
        self._archived = None
        self._group_name = None
        self._referenced_object_type = None
        self._name = None
        self._options = None
        self._calculation_formula = None
        self._has_unique_value = None
        self._field_type = None
        self._updated_user_id = None
        self._calculated = None
        self._external_options = None
        self._updated_at = None
        self.discriminator = None

        if created_user_id is not None:
            self.created_user_id = created_user_id
        if hidden is not None:
            self.hidden = hidden
        if modification_metadata is not None:
            self.modification_metadata = modification_metadata
        if display_order is not None:
            self.display_order = display_order
        self.description = description
        if show_currency_symbol is not None:
            self.show_currency_symbol = show_currency_symbol
        self.label = label
        self.type = type
        if hubspot_defined is not None:
            self.hubspot_defined = hubspot_defined
        if form_field is not None:
            self.form_field = form_field
        if created_at is not None:
            self.created_at = created_at
        if archived_at is not None:
            self.archived_at = archived_at
        if archived is not None:
            self.archived = archived
        self.group_name = group_name
        if referenced_object_type is not None:
            self.referenced_object_type = referenced_object_type
        self.name = name
        self.options = options
        if calculation_formula is not None:
            self.calculation_formula = calculation_formula
        if has_unique_value is not None:
            self.has_unique_value = has_unique_value
        self.field_type = field_type
        if updated_user_id is not None:
            self.updated_user_id = updated_user_id
        if calculated is not None:
            self.calculated = calculated
        if external_options is not None:
            self.external_options = external_options
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def created_user_id(self):
        """Gets the created_user_id of this ModelProperty.  # noqa: E501

        The internal user ID of the user who created the property in HubSpot. This field may not exist if the property was created outside of HubSpot.  # noqa: E501

        :return: The created_user_id of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._created_user_id

    @created_user_id.setter
    def created_user_id(self, created_user_id):
        """Sets the created_user_id of this ModelProperty.

        The internal user ID of the user who created the property in HubSpot. This field may not exist if the property was created outside of HubSpot.  # noqa: E501

        :param created_user_id: The created_user_id of this ModelProperty.  # noqa: E501
        :type created_user_id: str
        """

        self._created_user_id = created_user_id

    @property
    def hidden(self):
        """Gets the hidden of this ModelProperty.  # noqa: E501

        Whether or not the property will be hidden from the HubSpot UI. It's recommended this be set to false for custom properties.  # noqa: E501

        :return: The hidden of this ModelProperty.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this ModelProperty.

        Whether or not the property will be hidden from the HubSpot UI. It's recommended this be set to false for custom properties.  # noqa: E501

        :param hidden: The hidden of this ModelProperty.  # noqa: E501
        :type hidden: bool
        """

        self._hidden = hidden

    @property
    def modification_metadata(self):
        """Gets the modification_metadata of this ModelProperty.  # noqa: E501


        :return: The modification_metadata of this ModelProperty.  # noqa: E501
        :rtype: PropertyModificationMetadata
        """
        return self._modification_metadata

    @modification_metadata.setter
    def modification_metadata(self, modification_metadata):
        """Sets the modification_metadata of this ModelProperty.


        :param modification_metadata: The modification_metadata of this ModelProperty.  # noqa: E501
        :type modification_metadata: PropertyModificationMetadata
        """

        self._modification_metadata = modification_metadata

    @property
    def display_order(self):
        """Gets the display_order of this ModelProperty.  # noqa: E501

        Properties are shown in order, starting with the lowest positive integer value.  # noqa: E501

        :return: The display_order of this ModelProperty.  # noqa: E501
        :rtype: int
        """
        return self._display_order

    @display_order.setter
    def display_order(self, display_order):
        """Sets the display_order of this ModelProperty.

        Properties are shown in order, starting with the lowest positive integer value.  # noqa: E501

        :param display_order: The display_order of this ModelProperty.  # noqa: E501
        :type display_order: int
        """

        self._display_order = display_order

    @property
    def description(self):
        """Gets the description of this ModelProperty.  # noqa: E501

        A description of the property that will be shown as help text in HubSpot.  # noqa: E501

        :return: The description of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ModelProperty.

        A description of the property that will be shown as help text in HubSpot.  # noqa: E501

        :param description: The description of this ModelProperty.  # noqa: E501
        :type description: str
        """
        if self.local_vars_configuration.client_side_validation and description is None:  # noqa: E501
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def show_currency_symbol(self):
        """Gets the show_currency_symbol of this ModelProperty.  # noqa: E501

        Whether or not the property will display the currency symbol set in the account settings.  # noqa: E501

        :return: The show_currency_symbol of this ModelProperty.  # noqa: E501
        :rtype: bool
        """
        return self._show_currency_symbol

    @show_currency_symbol.setter
    def show_currency_symbol(self, show_currency_symbol):
        """Sets the show_currency_symbol of this ModelProperty.

        Whether or not the property will display the currency symbol set in the account settings.  # noqa: E501

        :param show_currency_symbol: The show_currency_symbol of this ModelProperty.  # noqa: E501
        :type show_currency_symbol: bool
        """

        self._show_currency_symbol = show_currency_symbol

    @property
    def label(self):
        """Gets the label of this ModelProperty.  # noqa: E501

        A human-readable property label that will be shown in HubSpot.  # noqa: E501

        :return: The label of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this ModelProperty.

        A human-readable property label that will be shown in HubSpot.  # noqa: E501

        :param label: The label of this ModelProperty.  # noqa: E501
        :type label: str
        """
        if self.local_vars_configuration.client_side_validation and label is None:  # noqa: E501
            raise ValueError("Invalid value for `label`, must not be `None`")  # noqa: E501

        self._label = label

    @property
    def type(self):
        """Gets the type of this ModelProperty.  # noqa: E501

        The property data type.  # noqa: E501

        :return: The type of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ModelProperty.

        The property data type.  # noqa: E501

        :param type: The type of this ModelProperty.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def hubspot_defined(self):
        """Gets the hubspot_defined of this ModelProperty.  # noqa: E501

        This will be true for default object properties built into HubSpot.  # noqa: E501

        :return: The hubspot_defined of this ModelProperty.  # noqa: E501
        :rtype: bool
        """
        return self._hubspot_defined

    @hubspot_defined.setter
    def hubspot_defined(self, hubspot_defined):
        """Sets the hubspot_defined of this ModelProperty.

        This will be true for default object properties built into HubSpot.  # noqa: E501

        :param hubspot_defined: The hubspot_defined of this ModelProperty.  # noqa: E501
        :type hubspot_defined: bool
        """

        self._hubspot_defined = hubspot_defined

    @property
    def form_field(self):
        """Gets the form_field of this ModelProperty.  # noqa: E501

        Whether or not the property can be used in a HubSpot form.  # noqa: E501

        :return: The form_field of this ModelProperty.  # noqa: E501
        :rtype: bool
        """
        return self._form_field

    @form_field.setter
    def form_field(self, form_field):
        """Sets the form_field of this ModelProperty.

        Whether or not the property can be used in a HubSpot form.  # noqa: E501

        :param form_field: The form_field of this ModelProperty.  # noqa: E501
        :type form_field: bool
        """

        self._form_field = form_field

    @property
    def created_at(self):
        """Gets the created_at of this ModelProperty.  # noqa: E501

          # noqa: E501

        :return: The created_at of this ModelProperty.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ModelProperty.

          # noqa: E501

        :param created_at: The created_at of this ModelProperty.  # noqa: E501
        :type created_at: datetime
        """

        self._created_at = created_at

    @property
    def archived_at(self):
        """Gets the archived_at of this ModelProperty.  # noqa: E501

        When the property was archived.  # noqa: E501

        :return: The archived_at of this ModelProperty.  # noqa: E501
        :rtype: datetime
        """
        return self._archived_at

    @archived_at.setter
    def archived_at(self, archived_at):
        """Sets the archived_at of this ModelProperty.

        When the property was archived.  # noqa: E501

        :param archived_at: The archived_at of this ModelProperty.  # noqa: E501
        :type archived_at: datetime
        """

        self._archived_at = archived_at

    @property
    def archived(self):
        """Gets the archived of this ModelProperty.  # noqa: E501

        Whether or not the property is archived.  # noqa: E501

        :return: The archived of this ModelProperty.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this ModelProperty.

        Whether or not the property is archived.  # noqa: E501

        :param archived: The archived of this ModelProperty.  # noqa: E501
        :type archived: bool
        """

        self._archived = archived

    @property
    def group_name(self):
        """Gets the group_name of this ModelProperty.  # noqa: E501

        The name of the property group the property belongs to.  # noqa: E501

        :return: The group_name of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._group_name

    @group_name.setter
    def group_name(self, group_name):
        """Sets the group_name of this ModelProperty.

        The name of the property group the property belongs to.  # noqa: E501

        :param group_name: The group_name of this ModelProperty.  # noqa: E501
        :type group_name: str
        """
        if self.local_vars_configuration.client_side_validation and group_name is None:  # noqa: E501
            raise ValueError("Invalid value for `group_name`, must not be `None`")  # noqa: E501

        self._group_name = group_name

    @property
    def referenced_object_type(self):
        """Gets the referenced_object_type of this ModelProperty.  # noqa: E501

        If this property is related to other object(s), they'll be listed here.  # noqa: E501

        :return: The referenced_object_type of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._referenced_object_type

    @referenced_object_type.setter
    def referenced_object_type(self, referenced_object_type):
        """Sets the referenced_object_type of this ModelProperty.

        If this property is related to other object(s), they'll be listed here.  # noqa: E501

        :param referenced_object_type: The referenced_object_type of this ModelProperty.  # noqa: E501
        :type referenced_object_type: str
        """

        self._referenced_object_type = referenced_object_type

    @property
    def name(self):
        """Gets the name of this ModelProperty.  # noqa: E501

        The internal property name, which must be used when referencing the property via the API.  # noqa: E501

        :return: The name of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ModelProperty.

        The internal property name, which must be used when referencing the property via the API.  # noqa: E501

        :param name: The name of this ModelProperty.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def options(self):
        """Gets the options of this ModelProperty.  # noqa: E501

        A list of valid options for the property. This field is required for enumerated properties, but will be empty for other property types.  # noqa: E501

        :return: The options of this ModelProperty.  # noqa: E501
        :rtype: list[Option]
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this ModelProperty.

        A list of valid options for the property. This field is required for enumerated properties, but will be empty for other property types.  # noqa: E501

        :param options: The options of this ModelProperty.  # noqa: E501
        :type options: list[Option]
        """
        if self.local_vars_configuration.client_side_validation and options is None:  # noqa: E501
            raise ValueError("Invalid value for `options`, must not be `None`")  # noqa: E501

        self._options = options

    @property
    def calculation_formula(self):
        """Gets the calculation_formula of this ModelProperty.  # noqa: E501

        Represents a formula that is used to compute a calculated property.  # noqa: E501

        :return: The calculation_formula of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._calculation_formula

    @calculation_formula.setter
    def calculation_formula(self, calculation_formula):
        """Sets the calculation_formula of this ModelProperty.

        Represents a formula that is used to compute a calculated property.  # noqa: E501

        :param calculation_formula: The calculation_formula of this ModelProperty.  # noqa: E501
        :type calculation_formula: str
        """

        self._calculation_formula = calculation_formula

    @property
    def has_unique_value(self):
        """Gets the has_unique_value of this ModelProperty.  # noqa: E501

        Whether or not the property's value must be unique. Once set, this can't be changed.  # noqa: E501

        :return: The has_unique_value of this ModelProperty.  # noqa: E501
        :rtype: bool
        """
        return self._has_unique_value

    @has_unique_value.setter
    def has_unique_value(self, has_unique_value):
        """Sets the has_unique_value of this ModelProperty.

        Whether or not the property's value must be unique. Once set, this can't be changed.  # noqa: E501

        :param has_unique_value: The has_unique_value of this ModelProperty.  # noqa: E501
        :type has_unique_value: bool
        """

        self._has_unique_value = has_unique_value

    @property
    def field_type(self):
        """Gets the field_type of this ModelProperty.  # noqa: E501

        Controls how the property appears in HubSpot.  # noqa: E501

        :return: The field_type of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._field_type

    @field_type.setter
    def field_type(self, field_type):
        """Sets the field_type of this ModelProperty.

        Controls how the property appears in HubSpot.  # noqa: E501

        :param field_type: The field_type of this ModelProperty.  # noqa: E501
        :type field_type: str
        """
        if self.local_vars_configuration.client_side_validation and field_type is None:  # noqa: E501
            raise ValueError("Invalid value for `field_type`, must not be `None`")  # noqa: E501

        self._field_type = field_type

    @property
    def updated_user_id(self):
        """Gets the updated_user_id of this ModelProperty.  # noqa: E501

        The internal user ID of the user who updated the property in HubSpot. This field may not exist if the property was updated outside of HubSpot.  # noqa: E501

        :return: The updated_user_id of this ModelProperty.  # noqa: E501
        :rtype: str
        """
        return self._updated_user_id

    @updated_user_id.setter
    def updated_user_id(self, updated_user_id):
        """Sets the updated_user_id of this ModelProperty.

        The internal user ID of the user who updated the property in HubSpot. This field may not exist if the property was updated outside of HubSpot.  # noqa: E501

        :param updated_user_id: The updated_user_id of this ModelProperty.  # noqa: E501
        :type updated_user_id: str
        """

        self._updated_user_id = updated_user_id

    @property
    def calculated(self):
        """Gets the calculated of this ModelProperty.  # noqa: E501

        For default properties, true indicates that the property is calculated by a HubSpot process. It has no effect for custom properties.  # noqa: E501

        :return: The calculated of this ModelProperty.  # noqa: E501
        :rtype: bool
        """
        return self._calculated

    @calculated.setter
    def calculated(self, calculated):
        """Sets the calculated of this ModelProperty.

        For default properties, true indicates that the property is calculated by a HubSpot process. It has no effect for custom properties.  # noqa: E501

        :param calculated: The calculated of this ModelProperty.  # noqa: E501
        :type calculated: bool
        """

        self._calculated = calculated

    @property
    def external_options(self):
        """Gets the external_options of this ModelProperty.  # noqa: E501

        For default properties, true indicates that the options are stored externally to the property settings.  # noqa: E501

        :return: The external_options of this ModelProperty.  # noqa: E501
        :rtype: bool
        """
        return self._external_options

    @external_options.setter
    def external_options(self, external_options):
        """Sets the external_options of this ModelProperty.

        For default properties, true indicates that the options are stored externally to the property settings.  # noqa: E501

        :param external_options: The external_options of this ModelProperty.  # noqa: E501
        :type external_options: bool
        """

        self._external_options = external_options

    @property
    def updated_at(self):
        """Gets the updated_at of this ModelProperty.  # noqa: E501

          # noqa: E501

        :return: The updated_at of this ModelProperty.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this ModelProperty.

          # noqa: E501

        :param updated_at: The updated_at of this ModelProperty.  # noqa: E501
        :type updated_at: datetime
        """

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelProperty):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelProperty):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Marketing Events

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.marketing.events.api.add_event_attendees_api import AddEventAttendeesApi
from hubspot.marketing.events.api.basic_api import BasicApi
from hubspot.marketing.events.api.batch_api import BatchApi
from hubspot.marketing.events.api.change_property_api import ChangePropertyApi
from hubspot.marketing.events.api.identifiers_api import IdentifiersApi
from hubspot.marketing.events.api.list_associations_api import ListAssociationsApi
from hubspot.marketing.events.api.retrieve_participant_state_api import RetrieveParticipantStateApi
from hubspot.marketing.events.api.settings_api import SettingsApi
from hubspot.marketing.events.api.subscriber_state_changes_api import SubscriberStateChangesApi

# import ApiClient
from hubspot.marketing.events.api_client import ApiClient
from hubspot.marketing.events.configuration import Configuration
from hubspot.marketing.events.exceptions import OpenApiException
from hubspot.marketing.events.exceptions import ApiTypeError
from hubspot.marketing.events.exceptions import ApiValueError
from hubspot.marketing.events.exceptions import ApiKeyError
from hubspot.marketing.events.exceptions import ApiAttributeError
from hubspot.marketing.events.exceptions import ApiException

# import models into sdk package
from hubspot.marketing.events.models.app_info import AppInfo
from hubspot.marketing.events.models.attendance_counters import AttendanceCounters
from hubspot.marketing.events.models.batch_input_marketing_event_create_request_params import BatchInputMarketingEventCreateRequestParams
from hubspot.marketing.events.models.batch_input_marketing_event_email_subscriber import BatchInputMarketingEventEmailSubscriber
from hubspot.marketing.events.models.batch_input_marketing_event_external_unique_identifier import BatchInputMarketingEventExternalUniqueIdentifier
from hubspot.marketing.events.models.batch_input_marketing_event_public_object_id_delete_request import BatchInputMarketingEventPublicObjectIdDeleteRequest
from hubspot.marketing.events.models.batch_input_marketing_event_public_update_request_full_v2 import BatchInputMarketingEventPublicUpdateRequestFullV2
from hubspot.marketing.events.models.batch_input_marketing_event_subscriber import BatchInputMarketingEventSubscriber
from hubspot.marketing.events.models.batch_response_marketing_event_public_default_response import BatchResponseMarketingEventPublicDefaultResponse
from hubspot.marketing.events.models.batch_response_marketing_event_public_default_response_v2 import BatchResponseMarketingEventPublicDefaultResponseV2
from hubspot.marketing.events.models.batch_response_marketing_event_public_default_response_v2_with_errors import BatchResponseMarketingEventPublicDefaultResponseV2WithErrors
from hubspot.marketing.events.models.batch_response_subscriber_email_response import BatchResponseSubscriberEmailResponse
from hubspot.marketing.events.models.batch_response_subscriber_vid_response import BatchResponseSubscriberVidResponse
from hubspot.marketing.events.models.collection_response_marketing_event_public_read_response_v2_forward_paging import CollectionResponseMarketingEventPublicReadResponseV2ForwardPaging
from hubspot.marketing.events.models.collection_response_search_public_response_wrapper_no_paging import CollectionResponseSearchPublicResponseWrapperNoPaging
from hubspot.marketing.events.models.collection_response_with_total_marketing_event_identifiers_response_no_paging import CollectionResponseWithTotalMarketingEventIdentifiersResponseNoPaging
from hubspot.marketing.events.models.collection_response_with_total_participation_breakdown_forward_paging import CollectionResponseWithTotalParticipationBreakdownForwardPaging
from hubspot.marketing.events.models.collection_response_with_total_public_list_no_paging import CollectionResponseWithTotalPublicListNoPaging
from hubspot.marketing.events.models.contact_association import ContactAssociation
from hubspot.marketing.events.models.crm_property_wrapper import CrmPropertyWrapper
from hubspot.marketing.events.models.error import Error
from hubspot.marketing.events.models.error_detail import ErrorDetail
from hubspot.marketing.events.models.event_detail_settings import EventDetailSettings
from hubspot.marketing.events.models.event_detail_settings_url import EventDetailSettingsUrl
from hubspot.marketing.events.models.forward_paging import ForwardPaging
from hubspot.marketing.events.models.marketing_event_association import MarketingEventAssociation
from hubspot.marketing.events.models.marketing_event_complete_request_params import MarketingEventCompleteRequestParams
from hubspot.marketing.events.models.marketing_event_create_request_params import MarketingEventCreateRequestParams
from hubspot.marketing.events.models.marketing_event_default_response import MarketingEventDefaultResponse
from hubspot.marketing.events.models.marketing_event_email_subscriber import MarketingEventEmailSubscriber
from hubspot.marketing.events.models.marketing_event_external_unique_identifier import MarketingEventExternalUniqueIdentifier
from hubspot.marketing.events.models.marketing_event_identifiers_response import MarketingEventIdentifiersResponse
from hubspot.marketing.events.models.marketing_event_public_default_response import MarketingEventPublicDefaultResponse
from hubspot.marketing.events.models.marketing_event_public_default_response_v2 import MarketingEventPublicDefaultResponseV2
from hubspot.marketing.events.models.marketing_event_public_object_id_delete_request import MarketingEventPublicObjectIdDeleteRequest
from hubspot.marketing.events.models.marketing_event_public_read_response import MarketingEventPublicReadResponse
from hubspot.marketing.events.models.marketing_event_public_read_response_v2 import MarketingEventPublicReadResponseV2
from hubspot.marketing.events.models.marketing_event_public_update_request_full_v2 import MarketingEventPublicUpdateRequestFullV2
from hubspot.marketing.events.models.marketing_event_public_update_request_v2 import MarketingEventPublicUpdateRequestV2
from hubspot.marketing.events.models.marketing_event_subscriber import MarketingEventSubscriber
from hubspot.marketing.events.models.marketing_event_update_request_params import MarketingEventUpdateRequestParams
from hubspot.marketing.events.models.next_page import NextPage
from hubspot.marketing.events.models.participation_associations import ParticipationAssociations
from hubspot.marketing.events.models.participation_breakdown import ParticipationBreakdown
from hubspot.marketing.events.models.participation_properties import ParticipationProperties
from hubspot.marketing.events.models.property_value import PropertyValue
from hubspot.marketing.events.models.public_list import PublicList
from hubspot.marketing.events.models.search_public_response_wrapper import SearchPublicResponseWrapper
from hubspot.marketing.events.models.standard_error import StandardError
from hubspot.marketing.events.models.subscriber_email_response import SubscriberEmailResponse
from hubspot.marketing.events.models.subscriber_vid_response import SubscriberVidResponse



# coding: utf-8

"""
    CRM Calling Extensions

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.extensions.calling.configuration import Configuration


class SettingsResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "created_at": "datetime",
        "supports_custom_objects": "bool",
        "uses_remote": "bool",
        "is_ready": "bool",
        "name": "str",
        "width": "int",
        "uses_calling_window": "bool",
        "supports_inbound_calling": "bool",
        "url": "str",
        "height": "int",
        "updated_at": "datetime",
    }

    attribute_map = {
        "created_at": "createdAt",
        "supports_custom_objects": "supportsCustomObjects",
        "uses_remote": "usesRemote",
        "is_ready": "isReady",
        "name": "name",
        "width": "width",
        "uses_calling_window": "usesCallingWindow",
        "supports_inbound_calling": "supportsInboundCalling",
        "url": "url",
        "height": "height",
        "updated_at": "updatedAt",
    }

    def __init__(
        self,
        created_at=None,
        supports_custom_objects=None,
        uses_remote=None,
        is_ready=None,
        name=None,
        width=None,
        uses_calling_window=None,
        supports_inbound_calling=None,
        url=None,
        height=None,
        updated_at=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """SettingsResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_at = None
        self._supports_custom_objects = None
        self._uses_remote = None
        self._is_ready = None
        self._name = None
        self._width = None
        self._uses_calling_window = None
        self._supports_inbound_calling = None
        self._url = None
        self._height = None
        self._updated_at = None
        self.discriminator = None

        self.created_at = created_at
        self.supports_custom_objects = supports_custom_objects
        self.uses_remote = uses_remote
        self.is_ready = is_ready
        self.name = name
        self.width = width
        self.uses_calling_window = uses_calling_window
        self.supports_inbound_calling = supports_inbound_calling
        self.url = url
        self.height = height
        self.updated_at = updated_at

    @property
    def created_at(self):
        """Gets the created_at of this SettingsResponse.  # noqa: E501

        When this calling extension was created.  # noqa: E501

        :return: The created_at of this SettingsResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this SettingsResponse.

        When this calling extension was created.  # noqa: E501

        :param created_at: The created_at of this SettingsResponse.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def supports_custom_objects(self):
        """Gets the supports_custom_objects of this SettingsResponse.  # noqa: E501

        When true, users will be able to click to dial from custom objects.  # noqa: E501

        :return: The supports_custom_objects of this SettingsResponse.  # noqa: E501
        :rtype: bool
        """
        return self._supports_custom_objects

    @supports_custom_objects.setter
    def supports_custom_objects(self, supports_custom_objects):
        """Sets the supports_custom_objects of this SettingsResponse.

        When true, users will be able to click to dial from custom objects.  # noqa: E501

        :param supports_custom_objects: The supports_custom_objects of this SettingsResponse.  # noqa: E501
        :type supports_custom_objects: bool
        """
        if self.local_vars_configuration.client_side_validation and supports_custom_objects is None:  # noqa: E501
            raise ValueError("Invalid value for `supports_custom_objects`, must not be `None`")  # noqa: E501

        self._supports_custom_objects = supports_custom_objects

    @property
    def uses_remote(self):
        """Gets the uses_remote of this SettingsResponse.  # noqa: E501

        When false, this indicates that your calling app does not use the anchored calling remote within the HubSpot app.   # noqa: E501

        :return: The uses_remote of this SettingsResponse.  # noqa: E501
        :rtype: bool
        """
        return self._uses_remote

    @uses_remote.setter
    def uses_remote(self, uses_remote):
        """Sets the uses_remote of this SettingsResponse.

        When false, this indicates that your calling app does not use the anchored calling remote within the HubSpot app.   # noqa: E501

        :param uses_remote: The uses_remote of this SettingsResponse.  # noqa: E501
        :type uses_remote: bool
        """
        if self.local_vars_configuration.client_side_validation and uses_remote is None:  # noqa: E501
            raise ValueError("Invalid value for `uses_remote`, must not be `None`")  # noqa: E501

        self._uses_remote = uses_remote

    @property
    def is_ready(self):
        """Gets the is_ready of this SettingsResponse.  # noqa: E501

        When true, this indicates that your calling app is ready for production. Users will be able to select your calling app as their provider and can then click to dial within HubSpot.  # noqa: E501

        :return: The is_ready of this SettingsResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_ready

    @is_ready.setter
    def is_ready(self, is_ready):
        """Sets the is_ready of this SettingsResponse.

        When true, this indicates that your calling app is ready for production. Users will be able to select your calling app as their provider and can then click to dial within HubSpot.  # noqa: E501

        :param is_ready: The is_ready of this SettingsResponse.  # noqa: E501
        :type is_ready: bool
        """
        if self.local_vars_configuration.client_side_validation and is_ready is None:  # noqa: E501
            raise ValueError("Invalid value for `is_ready`, must not be `None`")  # noqa: E501

        self._is_ready = is_ready

    @property
    def name(self):
        """Gets the name of this SettingsResponse.  # noqa: E501

        The name of your calling service to display to users.  # noqa: E501

        :return: The name of this SettingsResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SettingsResponse.

        The name of your calling service to display to users.  # noqa: E501

        :param name: The name of this SettingsResponse.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def width(self):
        """Gets the width of this SettingsResponse.  # noqa: E501

        The target width of the iframe that will contain your phone/calling UI.  # noqa: E501

        :return: The width of this SettingsResponse.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this SettingsResponse.

        The target width of the iframe that will contain your phone/calling UI.  # noqa: E501

        :param width: The width of this SettingsResponse.  # noqa: E501
        :type width: int
        """
        if self.local_vars_configuration.client_side_validation and width is None:  # noqa: E501
            raise ValueError("Invalid value for `width`, must not be `None`")  # noqa: E501

        self._width = width

    @property
    def uses_calling_window(self):
        """Gets the uses_calling_window of this SettingsResponse.  # noqa: E501

        When false, this indicates that your calling app does not require the use of the separate calling window to hold the call connection.   # noqa: E501

        :return: The uses_calling_window of this SettingsResponse.  # noqa: E501
        :rtype: bool
        """
        return self._uses_calling_window

    @uses_calling_window.setter
    def uses_calling_window(self, uses_calling_window):
        """Sets the uses_calling_window of this SettingsResponse.

        When false, this indicates that your calling app does not require the use of the separate calling window to hold the call connection.   # noqa: E501

        :param uses_calling_window: The uses_calling_window of this SettingsResponse.  # noqa: E501
        :type uses_calling_window: bool
        """
        if self.local_vars_configuration.client_side_validation and uses_calling_window is None:  # noqa: E501
            raise ValueError("Invalid value for `uses_calling_window`, must not be `None`")  # noqa: E501

        self._uses_calling_window = uses_calling_window

    @property
    def supports_inbound_calling(self):
        """Gets the supports_inbound_calling of this SettingsResponse.  # noqa: E501

        When true, this indicates that your calling app supports inbound calling within HubSpot.   # noqa: E501

        :return: The supports_inbound_calling of this SettingsResponse.  # noqa: E501
        :rtype: bool
        """
        return self._supports_inbound_calling

    @supports_inbound_calling.setter
    def supports_inbound_calling(self, supports_inbound_calling):
        """Sets the supports_inbound_calling of this SettingsResponse.

        When true, this indicates that your calling app supports inbound calling within HubSpot.   # noqa: E501

        :param supports_inbound_calling: The supports_inbound_calling of this SettingsResponse.  # noqa: E501
        :type supports_inbound_calling: bool
        """
        if self.local_vars_configuration.client_side_validation and supports_inbound_calling is None:  # noqa: E501
            raise ValueError("Invalid value for `supports_inbound_calling`, must not be `None`")  # noqa: E501

        self._supports_inbound_calling = supports_inbound_calling

    @property
    def url(self):
        """Gets the url of this SettingsResponse.  # noqa: E501

        The URL to your phone/calling UI, built with the [Calling SDK](#).  # noqa: E501

        :return: The url of this SettingsResponse.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this SettingsResponse.

        The URL to your phone/calling UI, built with the [Calling SDK](#).  # noqa: E501

        :param url: The url of this SettingsResponse.  # noqa: E501
        :type url: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def height(self):
        """Gets the height of this SettingsResponse.  # noqa: E501

        The target height of the iframe that will contain your phone/calling UI.  # noqa: E501

        :return: The height of this SettingsResponse.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this SettingsResponse.

        The target height of the iframe that will contain your phone/calling UI.  # noqa: E501

        :param height: The height of this SettingsResponse.  # noqa: E501
        :type height: int
        """
        if self.local_vars_configuration.client_side_validation and height is None:  # noqa: E501
            raise ValueError("Invalid value for `height`, must not be `None`")  # noqa: E501

        self._height = height

    @property
    def updated_at(self):
        """Gets the updated_at of this SettingsResponse.  # noqa: E501

        The last time the settings for this calling extension were modified.  # noqa: E501

        :return: The updated_at of this SettingsResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this SettingsResponse.

        The last time the settings for this calling extension were modified.  # noqa: E501

        :param updated_at: The updated_at of this SettingsResponse.  # noqa: E501
        :type updated_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SettingsResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SettingsResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Posts

    Use these endpoints for interacting with Blog Posts, Blog Authors, and Blog Tags  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.cms.blogs.blog_posts.api_client import ApiClient
from hubspot.cms.blogs.blog_posts.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class MultiLanguageApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def attach_to_lang_group(self, attach_to_lang_primary_request_v_next, **kwargs):  # noqa: E501
        """Attach post to a multi-language group  # noqa: E501

        Attach a blog post to a [multi-language group](https://developers.hubspot.com/docs/guides/cms/content/multi-language-content).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.attach_to_lang_group(attach_to_lang_primary_request_v_next, async_req=True)
        >>> result = thread.get()

        :param attach_to_lang_primary_request_v_next: The JSON representation of the AttachToLangPrimaryRequest object. (required)
        :type attach_to_lang_primary_request_v_next: AttachToLangPrimaryRequestVNext
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.attach_to_lang_group_with_http_info(attach_to_lang_primary_request_v_next, **kwargs)  # noqa: E501

    def attach_to_lang_group_with_http_info(self, attach_to_lang_primary_request_v_next, **kwargs):  # noqa: E501
        """Attach post to a multi-language group  # noqa: E501

        Attach a blog post to a [multi-language group](https://developers.hubspot.com/docs/guides/cms/content/multi-language-content).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.attach_to_lang_group_with_http_info(attach_to_lang_primary_request_v_next, async_req=True)
        >>> result = thread.get()

        :param attach_to_lang_primary_request_v_next: The JSON representation of the AttachToLangPrimaryRequest object. (required)
        :type attach_to_lang_primary_request_v_next: AttachToLangPrimaryRequestVNext
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["attach_to_lang_primary_request_v_next"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method attach_to_lang_group" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'attach_to_lang_primary_request_v_next' is set
        if self.api_client.client_side_validation and local_var_params.get("attach_to_lang_primary_request_v_next") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `attach_to_lang_primary_request_v_next` when calling `attach_to_lang_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "attach_to_lang_primary_request_v_next" in local_var_params:
            body_params = local_var_params["attach_to_lang_primary_request_v_next"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/cms/v3/blogs/posts/multi-language/attach-to-lang-group",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def create_lang_variation(self, blog_post_language_clone_request_v_next, **kwargs):  # noqa: E501
        """Create a language variation  # noqa: E501

        Create a new language variation from an existing blog post  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_lang_variation(blog_post_language_clone_request_v_next, async_req=True)
        >>> result = thread.get()

        :param blog_post_language_clone_request_v_next: The JSON representation of the BlogPostLanguageCloneRequestVNext object. (required)
        :type blog_post_language_clone_request_v_next: BlogPostLanguageCloneRequestVNext
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BlogPost
        """
        kwargs["_return_http_data_only"] = True
        return self.create_lang_variation_with_http_info(blog_post_language_clone_request_v_next, **kwargs)  # noqa: E501

    def create_lang_variation_with_http_info(self, blog_post_language_clone_request_v_next, **kwargs):  # noqa: E501
        """Create a language variation  # noqa: E501

        Create a new language variation from an existing blog post  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_lang_variation_with_http_info(blog_post_language_clone_request_v_next, async_req=True)
        >>> result = thread.get()

        :param blog_post_language_clone_request_v_next: The JSON representation of the BlogPostLanguageCloneRequestVNext object. (required)
        :type blog_post_language_clone_request_v_next: BlogPostLanguageCloneRequestVNext
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BlogPost, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["blog_post_language_clone_request_v_next"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method create_lang_variation" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'blog_post_language_clone_request_v_next' is set
        if self.api_client.client_side_validation and local_var_params.get("blog_post_language_clone_request_v_next") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `blog_post_language_clone_request_v_next` when calling `create_lang_variation`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "blog_post_language_clone_request_v_next" in local_var_params:
            body_params = local_var_params["blog_post_language_clone_request_v_next"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "BlogPost",
        }

        return self.api_client.call_api(
            "/cms/v3/blogs/posts/multi-language/create-language-variation",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def detach_from_lang_group(self, detach_from_lang_group_request_v_next, **kwargs):  # noqa: E501
        """Detach post from a multi-language group  # noqa: E501

        Detach a blog post from a [multi-language group](https://developers.hubspot.com/docs/guides/cms/content/multi-language-content).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.detach_from_lang_group(detach_from_lang_group_request_v_next, async_req=True)
        >>> result = thread.get()

        :param detach_from_lang_group_request_v_next: The JSON representation of the DetachFromLangGroupRequest object. (required)
        :type detach_from_lang_group_request_v_next: DetachFromLangGroupRequestVNext
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.detach_from_lang_group_with_http_info(detach_from_lang_group_request_v_next, **kwargs)  # noqa: E501

    def detach_from_lang_group_with_http_info(self, detach_from_lang_group_request_v_next, **kwargs):  # noqa: E501
        """Detach post from a multi-language group  # noqa: E501

        Detach a blog post from a [multi-language group](https://developers.hubspot.com/docs/guides/cms/content/multi-language-content).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.detach_from_lang_group_with_http_info(detach_from_lang_group_request_v_next, async_req=True)
        >>> result = thread.get()

        :param detach_from_lang_group_request_v_next: The JSON representation of the DetachFromLangGroupRequest object. (required)
        :type detach_from_lang_group_request_v_next: DetachFromLangGroupRequestVNext
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["detach_from_lang_group_request_v_next"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method detach_from_lang_group" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'detach_from_lang_group_request_v_next' is set
        if self.api_client.client_side_validation and local_var_params.get("detach_from_lang_group_request_v_next") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `detach_from_lang_group_request_v_next` when calling `detach_from_lang_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "detach_from_lang_group_request_v_next" in local_var_params:
            body_params = local_var_params["detach_from_lang_group_request_v_next"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/cms/v3/blogs/posts/multi-language/detach-from-lang-group",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def set_lang_primary(self, set_new_language_primary_request_v_next, **kwargs):  # noqa: E501
        """Set a new primary language  # noqa: E501

        Set the primary language of a [multi-language group](https://developers.hubspot.com/docs/guides/cms/content/multi-language-content) to the language of the provided post (specified as an ID in the request body)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.set_lang_primary(set_new_language_primary_request_v_next, async_req=True)
        >>> result = thread.get()

        :param set_new_language_primary_request_v_next: The JSON representation of the SetNewLanguagePrimaryRequest object. (required)
        :type set_new_language_primary_request_v_next: SetNewLanguagePrimaryRequestVNext
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.set_lang_primary_with_http_info(set_new_language_primary_request_v_next, **kwargs)  # noqa: E501

    def set_lang_primary_with_http_info(self, set_new_language_primary_request_v_next, **kwargs):  # noqa: E501
        """Set a new primary language  # noqa: E501

        Set the primary language of a [multi-language group](https://developers.hubspot.com/docs/guides/cms/content/multi-language-content) to the language of the provided post (specified as an ID in the request body)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.set_lang_primary_with_http_info(set_new_language_primary_request_v_next, async_req=True)
        >>> result = thread.get()

        :param set_new_language_primary_request_v_next: The JSON representation of the SetNewLanguagePrimaryRequest object. (required)
        :type set_new_language_primary_request_v_next: SetNewLanguagePrimaryRequestVNext
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["set_new_language_primary_request_v_next"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method set_lang_primary" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'set_new_language_primary_request_v_next' is set
        if self.api_client.client_side_validation and local_var_params.get("set_new_language_primary_request_v_next") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `set_new_language_primary_request_v_next` when calling `set_lang_primary`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "set_new_language_primary_request_v_next" in local_var_params:
            body_params = local_var_params["set_new_language_primary_request_v_next"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PUT", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/cms/v3/blogs/posts/multi-language/set-new-lang-primary",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def update_langs(self, update_languages_request_v_next, **kwargs):  # noqa: E501
        """Update languages of multi-language group  # noqa: E501

        Explicitly set new languages for each post in a [multi-language group](https://developers.hubspot.com/docs/guides/cms/content/multi-language-content).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_langs(update_languages_request_v_next, async_req=True)
        >>> result = thread.get()

        :param update_languages_request_v_next: The JSON representation of the SetNewLanguagePrimaryRequest object. (required)
        :type update_languages_request_v_next: UpdateLanguagesRequestVNext
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.update_langs_with_http_info(update_languages_request_v_next, **kwargs)  # noqa: E501

    def update_langs_with_http_info(self, update_languages_request_v_next, **kwargs):  # noqa: E501
        """Update languages of multi-language group  # noqa: E501

        Explicitly set new languages for each post in a [multi-language group](https://developers.hubspot.com/docs/guides/cms/content/multi-language-content).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_langs_with_http_info(update_languages_request_v_next, async_req=True)
        >>> result = thread.get()

        :param update_languages_request_v_next: The JSON representation of the SetNewLanguagePrimaryRequest object. (required)
        :type update_languages_request_v_next: UpdateLanguagesRequestVNext
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["update_languages_request_v_next"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method update_langs" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'update_languages_request_v_next' is set
        if self.api_client.client_side_validation and local_var_params.get("update_languages_request_v_next") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `update_languages_request_v_next` when calling `update_langs`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_languages_request_v_next" in local_var_params:
            body_params = local_var_params["update_languages_request_v_next"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/cms/v3/blogs/posts/multi-language/update-languages",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



# coding: utf-8

"""
    Line Items

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.crm.line_items.api_client import ApiClient
from hubspot.crm.line_items.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class BasicApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive(self, line_item_id, **kwargs):  # noqa: E501
        """Archive  # noqa: E501

        Move an Object identified by `{lineItemId}` to the recycling bin.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive(line_item_id, async_req=True)
        >>> result = thread.get()

        :param line_item_id: (required)
        :type line_item_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.archive_with_http_info(line_item_id, **kwargs)  # noqa: E501

    def archive_with_http_info(self, line_item_id, **kwargs):  # noqa: E501
        """Archive  # noqa: E501

        Move an Object identified by `{lineItemId}` to the recycling bin.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_with_http_info(line_item_id, async_req=True)
        >>> result = thread.get()

        :param line_item_id: (required)
        :type line_item_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["line_item_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method archive" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'line_item_id' is set
        if self.api_client.client_side_validation and local_var_params.get("line_item_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `line_item_id` when calling `archive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "line_item_id" in local_var_params:
            path_params["lineItemId"] = local_var_params["line_item_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/crm/v3/objects/line_items/{lineItemId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def create(self, simple_public_object_input_for_create, **kwargs):  # noqa: E501
        """Create  # noqa: E501

        Create a line item with the given properties and return a copy of the object, including the ID. Documentation and examples for creating standard line items is provided.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create(simple_public_object_input_for_create, async_req=True)
        >>> result = thread.get()

        :param simple_public_object_input_for_create: (required)
        :type simple_public_object_input_for_create: SimplePublicObjectInputForCreate
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SimplePublicObject
        """
        kwargs["_return_http_data_only"] = True
        return self.create_with_http_info(simple_public_object_input_for_create, **kwargs)  # noqa: E501

    def create_with_http_info(self, simple_public_object_input_for_create, **kwargs):  # noqa: E501
        """Create  # noqa: E501

        Create a line item with the given properties and return a copy of the object, including the ID. Documentation and examples for creating standard line items is provided.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_with_http_info(simple_public_object_input_for_create, async_req=True)
        >>> result = thread.get()

        :param simple_public_object_input_for_create: (required)
        :type simple_public_object_input_for_create: SimplePublicObjectInputForCreate
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SimplePublicObject, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["simple_public_object_input_for_create"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method create" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'simple_public_object_input_for_create' is set
        if self.api_client.client_side_validation and local_var_params.get("simple_public_object_input_for_create") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `simple_public_object_input_for_create` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "simple_public_object_input_for_create" in local_var_params:
            body_params = local_var_params["simple_public_object_input_for_create"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            201: "SimplePublicObject",
        }

        return self.api_client.call_api(
            "/crm/v3/objects/line_items",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_by_id(self, line_item_id, **kwargs):  # noqa: E501
        """Read  # noqa: E501

        Read an Object identified by `{lineItemId}`. `{lineItemId}` refers to the internal object ID by default, or optionally any unique property value as specified by the `idProperty` query param.  Control what is returned via the `properties` query param.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id(line_item_id, async_req=True)
        >>> result = thread.get()

        :param line_item_id: (required)
        :type line_item_id: str
        :param properties: A comma separated list of the properties to be returned in the response. If any of the specified properties are not present on the requested object(s), they will be ignored.
        :type properties: list[str]
        :param properties_with_history: A comma separated list of the properties to be returned along with their history of previous values. If any of the specified properties are not present on the requested object(s), they will be ignored.
        :type properties_with_history: list[str]
        :param associations: A comma separated list of object types to retrieve associated IDs for. If any of the specified associations do not exist, they will be ignored.
        :type associations: list[str]
        :param archived: Whether to return only results that have been archived.
        :type archived: bool
        :param id_property: The name of a property whose values are unique for this object
        :type id_property: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SimplePublicObjectWithAssociations
        """
        kwargs["_return_http_data_only"] = True
        return self.get_by_id_with_http_info(line_item_id, **kwargs)  # noqa: E501

    def get_by_id_with_http_info(self, line_item_id, **kwargs):  # noqa: E501
        """Read  # noqa: E501

        Read an Object identified by `{lineItemId}`. `{lineItemId}` refers to the internal object ID by default, or optionally any unique property value as specified by the `idProperty` query param.  Control what is returned via the `properties` query param.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id_with_http_info(line_item_id, async_req=True)
        >>> result = thread.get()

        :param line_item_id: (required)
        :type line_item_id: str
        :param properties: A comma separated list of the properties to be returned in the response. If any of the specified properties are not present on the requested object(s), they will be ignored.
        :type properties: list[str]
        :param properties_with_history: A comma separated list of the properties to be returned along with their history of previous values. If any of the specified properties are not present on the requested object(s), they will be ignored.
        :type properties_with_history: list[str]
        :param associations: A comma separated list of object types to retrieve associated IDs for. If any of the specified associations do not exist, they will be ignored.
        :type associations: list[str]
        :param archived: Whether to return only results that have been archived.
        :type archived: bool
        :param id_property: The name of a property whose values are unique for this object
        :type id_property: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SimplePublicObjectWithAssociations, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["line_item_id", "properties", "properties_with_history", "associations", "archived", "id_property"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_by_id" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'line_item_id' is set
        if self.api_client.client_side_validation and local_var_params.get("line_item_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `line_item_id` when calling `get_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "line_item_id" in local_var_params:
            path_params["lineItemId"] = local_var_params["line_item_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("properties") is not None:  # noqa: E501
            query_params.append(("properties", local_var_params["properties"]))  # noqa: E501
            collection_formats["properties"] = "multi"  # noqa: E501
        if local_var_params.get("properties_with_history") is not None:  # noqa: E501
            query_params.append(("propertiesWithHistory", local_var_params["properties_with_history"]))  # noqa: E501
            collection_formats["propertiesWithHistory"] = "multi"  # noqa: E501
        if local_var_params.get("associations") is not None:  # noqa: E501
            query_params.append(("associations", local_var_params["associations"]))  # noqa: E501
            collection_formats["associations"] = "multi"  # noqa: E501
        if local_var_params.get("archived") is not None:  # noqa: E501
            query_params.append(("archived", local_var_params["archived"]))  # noqa: E501
        if local_var_params.get("id_property") is not None:  # noqa: E501
            query_params.append(("idProperty", local_var_params["id_property"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "SimplePublicObjectWithAssociations",
        }

        return self.api_client.call_api(
            "/crm/v3/objects/line_items/{lineItemId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_page(self, **kwargs):  # noqa: E501
        """List  # noqa: E501

        Read a page of line items. Control what is returned via the `properties` query param.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_page(async_req=True)
        >>> result = thread.get()

        :param limit: The maximum number of results to display per page.
        :type limit: int
        :param after: The paging cursor token of the last successfully read resource will be returned as the `paging.next.after` JSON property of a paged response containing more results.
        :type after: str
        :param properties: A comma separated list of the properties to be returned in the response. If any of the specified properties are not present on the requested object(s), they will be ignored.
        :type properties: list[str]
        :param properties_with_history: A comma separated list of the properties to be returned along with their history of previous values. If any of the specified properties are not present on the requested object(s), they will be ignored. Usage of this parameter will reduce the maximum number of objects that can be read by a single request.
        :type properties_with_history: list[str]
        :param associations: A comma separated list of object types to retrieve associated IDs for. If any of the specified associations do not exist, they will be ignored.
        :type associations: list[str]
        :param archived: Whether to return only results that have been archived.
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CollectionResponseSimplePublicObjectWithAssociationsForwardPaging
        """
        kwargs["_return_http_data_only"] = True
        return self.get_page_with_http_info(**kwargs)  # noqa: E501

    def get_page_with_http_info(self, **kwargs):  # noqa: E501
        """List  # noqa: E501

        Read a page of line items. Control what is returned via the `properties` query param.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_page_with_http_info(async_req=True)
        >>> result = thread.get()

        :param limit: The maximum number of results to display per page.
        :type limit: int
        :param after: The paging cursor token of the last successfully read resource will be returned as the `paging.next.after` JSON property of a paged response containing more results.
        :type after: str
        :param properties: A comma separated list of the properties to be returned in the response. If any of the specified properties are not present on the requested object(s), they will be ignored.
        :type properties: list[str]
        :param properties_with_history: A comma separated list of the properties to be returned along with their history of previous values. If any of the specified properties are not present on the requested object(s), they will be ignored. Usage of this parameter will reduce the maximum number of objects that can be read by a single request.
        :type properties_with_history: list[str]
        :param associations: A comma separated list of object types to retrieve associated IDs for. If any of the specified associations do not exist, they will be ignored.
        :type associations: list[str]
        :param archived: Whether to return only results that have been archived.
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CollectionResponseSimplePublicObjectWithAssociationsForwardPaging, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["limit", "after", "properties", "properties_with_history", "associations", "archived"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_page" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if local_var_params.get("limit") is not None:  # noqa: E501
            query_params.append(("limit", local_var_params["limit"]))  # noqa: E501
        if local_var_params.get("after") is not None:  # noqa: E501
            query_params.append(("after", local_var_params["after"]))  # noqa: E501
        if local_var_params.get("properties") is not None:  # noqa: E501
            query_params.append(("properties", local_var_params["properties"]))  # noqa: E501
            collection_formats["properties"] = "multi"  # noqa: E501
        if local_var_params.get("properties_with_history") is not None:  # noqa: E501
            query_params.append(("propertiesWithHistory", local_var_params["properties_with_history"]))  # noqa: E501
            collection_formats["propertiesWithHistory"] = "multi"  # noqa: E501
        if local_var_params.get("associations") is not None:  # noqa: E501
            query_params.append(("associations", local_var_params["associations"]))  # noqa: E501
            collection_formats["associations"] = "multi"  # noqa: E501
        if local_var_params.get("archived") is not None:  # noqa: E501
            query_params.append(("archived", local_var_params["archived"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "CollectionResponseSimplePublicObjectWithAssociationsForwardPaging",
        }

        return self.api_client.call_api(
            "/crm/v3/objects/line_items",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def update(self, line_item_id, simple_public_object_input, **kwargs):  # noqa: E501
        """Update  # noqa: E501

        Perform a partial update of an Object identified by `{lineItemId}`or optionally a unique property value as specified by the `idProperty` query param. `{lineItemId}` refers to the internal object ID by default, and the `idProperty` query param refers to a property whose values are unique for the object. Provided property values will be overwritten. Read-only and non-existent properties will result in an error. Properties values can be cleared by passing an empty string.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update(line_item_id, simple_public_object_input, async_req=True)
        >>> result = thread.get()

        :param line_item_id: (required)
        :type line_item_id: str
        :param simple_public_object_input: (required)
        :type simple_public_object_input: SimplePublicObjectInput
        :param id_property: The name of a property whose values are unique for this object
        :type id_property: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SimplePublicObject
        """
        kwargs["_return_http_data_only"] = True
        return self.update_with_http_info(line_item_id, simple_public_object_input, **kwargs)  # noqa: E501

    def update_with_http_info(self, line_item_id, simple_public_object_input, **kwargs):  # noqa: E501
        """Update  # noqa: E501

        Perform a partial update of an Object identified by `{lineItemId}`or optionally a unique property value as specified by the `idProperty` query param. `{lineItemId}` refers to the internal object ID by default, and the `idProperty` query param refers to a property whose values are unique for the object. Provided property values will be overwritten. Read-only and non-existent properties will result in an error. Properties values can be cleared by passing an empty string.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_with_http_info(line_item_id, simple_public_object_input, async_req=True)
        >>> result = thread.get()

        :param line_item_id: (required)
        :type line_item_id: str
        :param simple_public_object_input: (required)
        :type simple_public_object_input: SimplePublicObjectInput
        :param id_property: The name of a property whose values are unique for this object
        :type id_property: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SimplePublicObject, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["line_item_id", "simple_public_object_input", "id_property"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method update" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'line_item_id' is set
        if self.api_client.client_side_validation and local_var_params.get("line_item_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `line_item_id` when calling `update`")  # noqa: E501
        # verify the required parameter 'simple_public_object_input' is set
        if self.api_client.client_side_validation and local_var_params.get("simple_public_object_input") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `simple_public_object_input` when calling `update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "line_item_id" in local_var_params:
            path_params["lineItemId"] = local_var_params["line_item_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("id_property") is not None:  # noqa: E501
            query_params.append(("idProperty", local_var_params["id_property"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "simple_public_object_input" in local_var_params:
            body_params = local_var_params["simple_public_object_input"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PATCH", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "SimplePublicObject",
        }

        return self.api_client.call_api(
            "/crm/v3/objects/line_items/{lineItemId}",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )
